@@ -27,7 +27,15 @@ add_step <- function(dat = ., vars) {
     newdat %>% dplyr::arrange(bin, -step)
 }
 
-as.num <- function(x) { as.numeric(as.character(x)) }
+as.num <- function(x) {
+  if (is.numeric(x)) {
+    x
+  } else if (is.factor(x)) {
+    as.integer(x)
+  } else {
+    as.numeric(as.character(x))
+  }
+}
 
 convert_to_dense_grid <- function(dat, t = "t", id = "id", t_start = 0, t_step = 1, add = NULL) {
   t = seq(from=t_start, to=max(dat$t), by=t_step)
@@ -39,32 +47,32 @@ convert_to_dense_grid <- function(dat, t = "t", id = "id", t_start = 0, t_step =
   tmp$rtte <- 0
   tmp[match(id_t, paste0(tmp$id,"-",tmp$t)),]$rtte <- 1
   if (!is.null(add)) {
-    tmp2 <- merge(tmp, dat[,c("id", add)] %>% dplyr::group_by_("id") %>% dplyr::do(.[1,]), by = "id", all.y = FALSE)
+    tmp2 <- merge(tmp, dat[,c("id", add)] %>% dplyr::group_by(.data$id) %>% dplyr::slice(1), by = "id", all.y = FALSE)
   }
   return(tmp2)
 }
 
 relative_times <- function (dat, simulation = FALSE) {
   if (simulation) {
-    tmp <- dat %>% dplyr::group_by_("sim", "id")
+    tmp <- dat %>% dplyr::group_by(sim, id)
   } else {
-    tmp <- dat %>% dplyr::group_by_("id")
+    tmp <- dat %>% dplyr::group_by(id)
   }
-  tmp2 <- tmp %>% dplyr::arrange_("time") %>% dplyr::mutate(time = c(time[1], diff(time)))
+  tmp2 <- tmp %>% dplyr::arrange(time) %>% dplyr::mutate(time = c(time[1], diff(time)))
   if (simulation) {
-    return(tmp2 %>% dplyr::arrange_("sim", "id", "time"))
+    return(tmp2 %>% dplyr::arrange(sim, id, time))
   } else {
-    return(tmp2 %>% dplyr::arrange_("id", "time"))
+    return(tmp2 %>% dplyr::arrange(id, time))
   }
 }
 
-convert_from_dense_grid <- function (dat) { 
+convert_from_dense_grid <- function (dat) {
   ## Note RK: only for a single trial, requires a loop or ddply for multiple subproblems
-  tmp <- dat %>% dplyr::group_by_("id")
+  tmp <- dat %>% dplyr::group_by(.data$id)
   if("rtte" %in% names(dat)) {
     tmp <- tmp %>% dplyr::filter(rtte == 1)
   }
   tmp2 <- rbind(tmp %>% dplyr::filter(length(time) > 1) %>% dplyr::mutate(time = time - c(0,time[1:(length(time)-1)])),
                 tmp %>% dplyr::filter(length(time) == 1) )
-  return(tmp2 %>% dplyr::arrange_("id", "time"))
+  return(tmp2 %>% dplyr::arrange(.data$id, .data$time))
 }
