@@ -1,13 +1,13 @@
 #' Replace list elements by name
-#' 
+#'
 #' @param list original list
 #' @param replacement replacement list
 #' @details
-#' Finds and replaces list elements by name and throws an error if an 
+#' Finds and replaces list elements by name and throws an error if an
 #'    element is not available in the original list. This is a local duplicate
 #'    of the PKPDmisc copy for the VPC package to reduce dependency on PKPDmisc
 #'    at this time.
-#' @examples 
+#' @examples
 #' \dontrun{
 #' list <- list(ipred = "ipred", dv = "dv", idv = "idv", "pred" = "pred")
 #' replacement <- list(dv = "conc", idv = "time")
@@ -21,5 +21,5 @@ replace_list_elements <- function(list, replacement) {
     replacement <- replacement[-missing]
   }
   list[names(replacement)] <- lapply(names(replacement), function(x) list[[x]] <- replacement[[x]])
-  return(list)
-}
\ No newline at end of file
+  list
+}
